.. :changelog:

History
-------

0.1.1 (2018-06-04)
++++++++++++++++++

* The app is now usable as a very limited alpha
  * Email options advertised in readme are not implemented
  * Templates could use some work
* Add default templates
* Add configuration options

0.1.0 (2018-06-03)
++++++++++++++++++

* Initial release, demonstration of models and core logic
